Learn R Programming

wizaRdry (version 0.6.4)

getSurvey: Alias for 'qualtrics' (DEPRECATED)

Description

This function is deprecated. Please use 'qualtrics' instead. This is a legacy alias for the 'qualtrics' function to maintain compatibility with older code.

Usage

getSurvey(...)

Value

A cleaned and harmonized data frame containing the survey data with superkeys first.

Arguments

...

Optional column names to filter for. Only rows with non-missing values in ALL specified columns will be returned. This is useful for filtering data to only include complete cases for specific variables of interest.

Examples

Run this code
if (FALSE) {
# DEPRECATED - use qualtrics() instead
survey_data <- getSurvey("your_survey_alias")
}

Run the code above in your browser using DataLab