Learn R Programming

wizaRdry (version 0.6.4)

mongo: Fetch data from MongoDB to be stored in a data frame - UPDATED VERSION

Description

Fetch data from MongoDB to be stored in a data frame - UPDATED VERSION

Usage

mongo(
  collection,
  ...,
  database = NULL,
  identifier = NULL,
  chunk_size = NULL,
  verbose = FALSE,
  interview_date = NULL
)

Value

A data frame containing the MongoDB data with superkeys first

Arguments

collection

The name of the MongoDB collection

...

Optional column names to filter for. Only rows with non-missing values in ALL specified columns will be returned. This is useful for filtering data to only include complete cases for specific variables of interest.

database

The database name (optional)

identifier

Field to use as identifier (optional)

chunk_size

Number of records per chunk (optional)

verbose

Logical; if TRUE, displays detailed progress messages. Default is FALSE.

interview_date

Optional; can be either: - A date string in various formats (ISO, US, etc.) to filter data up to that date - A boolean TRUE to return only rows with non-NA interview_date values

Examples

Run this code
if (FALSE) {
# Get data from MongoDB collection
data <- mongo("collection")
}

Run the code above in your browser using DataLab