Learn R Programming

wizaRdry (version 0.6.4)

mongo.index: Display table of available MongoDB collections

Description

Retrieves a list of all available collections in the configured MongoDB database.

Usage

mongo.index(database = NULL)

Value

A character vector containing the names of all available collections in the configured MongoDB database.

Arguments

database

Optional; the name of the database to connect to. If NULL, uses the database specified in the configuration file.