Learn R Programming

wizaRdry (version 0.6.4)

nda: Generate validated NDA submission templates created in the ./nda directory

Description

This function processes requests for clean data sequentially for specified measures. It makes a request to the NIH NDA API for the named data structures and runs the associated data remediation routines. It then runs a series of unit tests to verify that the data quality standards are met.

Usage

nda(
  ...,
  csv = FALSE,
  rdata = FALSE,
  spss = FALSE,
  limited_dataset = FALSE,
  skip_prompt = TRUE,
  verbose = FALSE,
  strict = TRUE,
  dcc = FALSE
)

Value

Prints the time taken for the data request process.

Arguments

...

Strings, specifying the measures to process, which can be a Mongo collection, REDCap instrument, or Qualtrics survey.

csv

Optional; Boolean, if TRUE creates a .csv extract in ./tmp.

rdata

Optional; Boolean, if TRUE creates an .rdata extract in ./tmp.

spss

Optional; Boolean, if TRUE creates a .sav extract in ./tmp.

limited_dataset

Optional; Boolean, if TRUE does not perform date-shifting of interview_date or age-capping of interview_age

skip_prompt

Logical. If TRUE (default), skips confirmation prompts unless preferences aren't set yet. If FALSE, prompts for confirmation unless the user has previously chosen to remember their preference.

verbose

Logical. If TRUE, shows detailed processing information. If FALSE (default), shows only essential user-facing messages.

strict

Logical. If TRUE (default), enforce strict NDA validation: required fields with ANY missing data or recommended fields with ALL missing data will cause validation failure. If FALSE (lenient mode), missing data triggers warnings but allows processing to continue.

dcc

Logical. If TRUE, include 11 DCC (Data Coordinating Center) fields from ndar_subject01 (7 required + 4 recommended). Default FALSE.

Author

Joshua Kenney joshua.kenney@yale.edu

Examples

Run this code
if (FALSE) {
  nda("prl", csv=TRUE)
  nda("rgpts", "kamin", rdata=TRUE)

  # Skip confirmation prompts
  nda("prl", csv=TRUE, skip_prompt=TRUE)
  
  # Show detailed processing information
  nda("prl", verbose=TRUE)
  
  # Use lenient validation mode (allow missing data with warnings)
  nda("prl", strict=FALSE)
  
  # Include DCC fields from ndar_subject01
  nda("prl", dcc=TRUE)
}

Run the code above in your browser using DataLab