Learn R Programming

wizaRdry (version 0.6.4)

ndaRequest: Alias for 'nda' (DEPRECATED)

Description

This function is deprecated. Please use 'nda' instead. This is a legacy alias for the 'nda' function to maintain compatibility with older code.

Usage

ndaRequest(...)

Value

Prints the time taken for the data request process.

Arguments

...

Strings, specifying the measures to process, which can be a Mongo collection, REDCap instrument, or Qualtrics survey.

Examples

Run this code
if (FALSE) {
# DEPRECATED - use nda() instead
prl01 <- ndaRequest("prl01")
}

Run the code above in your browser using DataLab