Learn R Programming

wizaRdry (version 0.6.4)

oracle.index: Get a list of tables from the Oracle database

Description

Get a list of tables from the Oracle database

Usage

oracle.index(schema = NULL)

Value

A data frame with table information

Arguments

schema

Optional schema name to filter tables