Learn R Programming

wizaRdry (version 0.6.4)

oracle.test: Test Oracle database connection

Description

Tests the connection to the Oracle database using the configured DSN and credentials. This is a simple connectivity test that doesn't perform any data operations.

Usage

oracle.test()

Arguments

Value

A logical value indicating whether the connection was successful

Examples

Run this code
if (FALSE) {
# Test the Oracle connection
if (oracle.test()) {
  message("Oracle connection successful!")
} else {
  message("Oracle connection failed!")
}
}

Run the code above in your browser using DataLab