- qualtrics_alias
The alias for the Qualtrics survey to be retrieved.
- ...
Optional column names to filter for. Only rows with non-missing values
in ALL specified columns will be returned. This is useful for filtering
data to only include complete cases for specific variables of interest.
- institution
Optional. The institution name (e.g., "temple" or "nu"). If NULL, all institutions will be searched.
- label
Logical indicating whether to return coded values or their associated labels (default is FALSE).
- interview_date
Optional; can be either:
- A date string in various formats (ISO, US, etc.) to filter data up to that date
- A boolean TRUE to return only rows with non-NA interview_date values
- complete
Logical; default FALSE, if TRUE only returns rows where Progress == 100