Optional column names to filter for. Only rows with non-missing values
in ALL specified columns will be returned. This is useful for filtering
data to only include complete cases for specific variables of interest.
raw_or_label
Whether to return raw or labeled values
redcap_event_name
Optional event name filter
batch_size
Number of records to retrieve per batch
records
Optional vector of specific record IDs
fields
Optional vector of specific fields
exclude_pii
Default TRUE remove all fields marked as identifiable
interview_date
Optional; can be either:
- A date string in various formats (ISO, US, etc.) to filter data up to that date
- A boolean TRUE to return only rows with non-NA interview_date values
date_format
Default ymd define date format for interview_date
complete
Option boolean TRUE will return only forms marked as complete in REDCap