powered by
This function is deprecated. Please use 'nda' instead. This is a legacy alias for the 'nda' function to maintain compatibility with older code.
ndaRequest(...)
Prints the time taken for the data request process.
Strings, specifying the measures to process, which can be a Mongo collection, REDCap instrument, or Qualtrics survey.
if (FALSE) { # DEPRECATED - use nda() instead prl01 <- ndaRequest("prl01") }
Run the code above in your browser using DataLab